@@ -80,6 +80,76 @@ fn it_works() {
     );
 }
 
+#[test]
+fn nearest_works_with_larger_example() {
+    let vertices = vec![
+        [68.91105387931276, 44.91668458105576],
+        [-34.58731474945385, 71.74034814015292],
+        [49.81627485893122, 13.441889056681546],
+        [-50.870681576138466, 52.66452496629904],
+        [-5.203156861316344, -20.99593863690137],
+        [43.60999031840865, -77.39431889881345],
+        [-2.587194808403382, 65.67594363600605],
+        [17.32701517519223, -77.53994704470668],
+        [-86.56502962282084, -88.9478905680815],
+        [45.673095545318176, 33.796801087673686],
+        [96.76125939245716, -16.121359071950366],
+        [-29.246599975853428, 24.744789767875034],
+        [-48.44195735538501, -16.431856700425442],
+        [-50.88742960065202, 24.931374210927416],
+        [96.27494950336964, 65.86741658775654],
+        [-24.966035194707842, 95.0731027560162],
+        [-76.39421787520853, 10.652314286279122],
+    ];
+
+    // test point is ~9 distance away from the last vertex inserted
+    let test_point = [-75.06202391475783, 1.9077480803729827];
+
+    let mut tree: KdTree<f64, (), 2> = KdTree::new();
+
+    for vertex in vertices {
+        tree.add(&vertex, ()).unwrap();
+    }
+    let nearest_distance = tree.nearest(&test_point, 1, &kiddo::distance::squared_euclidean).unwrap()[0].0.sqrt();
+
+    assert_eq!(nearest_distance, 8.845460919462422);
+}
+
+#[test]
+fn nearest_one_works_with_larger_example() {
+    let vertices = vec![
+        [68.91105387931276, 44.91668458105576],
+        [-34.58731474945385, 71.74034814015292],
+        [49.81627485893122, 13.441889056681546],
+        [-50.870681576138466, 52.66452496629904],
+        [-5.203156861316344, -20.99593863690137],
+        [43.60999031840865, -77.39431889881345],
+        [-2.587194808403382, 65.67594363600605],
+        [17.32701517519223, -77.53994704470668],
+        [-86.56502962282084, -88.9478905680815],
+        [45.673095545318176, 33.796801087673686],
+        [96.76125939245716, -16.121359071950366],
+        [-29.246599975853428, 24.744789767875034],
+        [-48.44195735538501, -16.431856700425442],
+        [-50.88742960065202, 24.931374210927416],
+        [96.27494950336964, 65.86741658775654],
+        [-24.966035194707842, 95.0731027560162],
+        [-76.39421787520853, 10.652314286279122],
+    ];
+
+    // test point is ~9 distance away from the last vertex inserted
+    let test_point = [-75.06202391475783, 1.9077480803729827];
+
+    let mut tree: KdTree<f64, (), 2> = KdTree::new();
+
+    for vertex in vertices {
+        tree.add(&vertex, ()).unwrap();
+    }
+    let nearest_distance = tree.nearest_one(&test_point, &kiddo::distance::squared_euclidean).unwrap().0.sqrt();
+
+    assert_eq!(nearest_distance, 8.845460919462422);
+}
+
 #[test]
 fn handles_non_finite_coordinate() {
     let point_a = ([std::f64::NAN, std::f64::NAN], 0f64);
@@ -318,3 +388,4 @@ fn error_messages_do_not_overflow_stack() {
     format!("{}", ErrorKind::ZeroCapacity);
     format!("{}", ErrorKind::Empty);
 }
+
